def to_unit_memory(number):
    """Creates a string representation of memory size given `number`."""
    kb = 1024

    number /= kb

    if number < 100:
        return '{} Kb'.format(round(number, 2))

    number /= kb
    if number < 300:
        return '{} Mb'.format(round(number, 2))

    number /= kb

    return '{} Gb'.format(round(number, 2))



from django.utils.timezone import now

DATETIME_FORMAT = "%Y-%m-%d %H:%M:%S %Z"


def log_spec(log_line, name='', timestamp=None, log_level=None):
    return '{timestamp}{log_level}{name} -- {log_line}'.format(
        log_line=log_line,
        name=' {}'.format(name) if name else '',
        timestamp=timestamp or now().strftime(DATETIME_FORMAT),
        log_level=' {}'.format(log_level) if log_level else '')



import pytz

from datetime import datetime

try:
    from django.utils.timezone import now
except ImportError:
    now = None


utc = pytz.utc


def now(tzinfo=None):
    """
    Return an aware or naive datetime.datetime, depending on settings.USE_TZ.
    """
    if now:
        return now

    if tzinfo:
        # timeit shows that datetime.now(tz=utc) is 24% slower
        return datetime.utcnow().replace(tzinfo=utc)
    else:
        return datetime.now()



from urllib.parse import urlparse


def validate_url(url):
    if not url.startswith(('http://', 'https://')):
        return False
    parsed = urlparse(url)
    if not parsed.hostname:
        return False
    return True

